--- a/ipsservices/ipssosplugin/inc/ipsplgpop3connectop.h Thu May 27 12:43:55 2010 +0300
+++ b/ipsservices/ipssosplugin/inc/ipsplgpop3connectop.h Fri Jun 11 13:27:14 2010 +0300
@@ -44,10 +44,13 @@
* @param aFSOperationObserver observer callback pointer
* @param aFSRequestId client assigned identifier for the request instance
* @param aEventHandler event handler for sending sync events
+ * @param aSignallingAllowed for asynchronous request response message
+ * @param aFetchWillFollow used when connection must be kept open
* @return new instance of the class
*/
// <qmail> MFSMailRequestObserver& changed to pointer
// <qmail> aSignallingAllowed parameter removed
static CIpsPlgPop3ConnectOp* NewL(
CMsvSession& aMsvSession,
TRequestStatus& aObserverRequestStatus,
@@ -57,7 +60,9 @@
TFSMailMsgId aFSMailBoxId,
MFSMailRequestObserver* aFSOperationObserver,
TInt aFSRequestId,
- CIpsPlgEventHandler* aEventHandler );
+ CIpsPlgEventHandler* aEventHandler,
+ TBool aSignallingAllowed=ETrue,
+ TBool aFetchWillFollow=EFalse );
/**
*
@@ -91,6 +96,8 @@
TIpsOpType IpsOpType() const;
// </qmail>
+ TInt GetOperationErrorCodeL( );
+
protected:
/**
@@ -109,7 +116,8 @@
*
*/
// <qmail> MFSMailRequestObserver& changed to pointer
// <qmail> aSignallingAllowed parameter removed
CIpsPlgPop3ConnectOp(
CMsvSession& aMsvSession,
TRequestStatus& aObserverRequestStatus,
@@ -119,7 +127,9 @@
TFSMailMsgId aFSMailBoxId,
MFSMailRequestObserver* aFSOperationObserver,
TInt aFSRequestId,
- CIpsPlgEventHandler* aEventHandler );
+ CIpsPlgEventHandler* aEventHandler,
+ TBool aSignallingAllowed,
+ TBool aFetchWillFollow );
/**
*
@@ -134,7 +144,8 @@
void DoPopulateL();
// <qmail> removed TBool ValidateL() (did nothing)
// <qmail> removed void DoQueryPasswordL() not used any more
- void DoDisconnect();
+ // <qmail> DoDisconnect -> DoDisconnectL
+ void DoDisconnectL();
// </qmail>
// <qmail> removed flag methods as they were not used or even defined anywhere
@@ -165,7 +176,10 @@
TBool iForcePopulate;
// <qmail> removed iSelection;
CIpsPlgEventHandler* iEventHandler; // not owned
- TBool iAlreadyConnected;
+ // <qmail> iAlreadyConnected removed
+ // <qmail>
+ TBool iFetchWillFollow;
+ // </qmail>
};
#endif
@@ -44,10 +44,13 @@
*/
// <qmail> MFSMailRequestObserver& changed to pointer
- // <qmail> aSignallingAllowed parameter removed
+ // <qmail> aSignallingAllowed parameter added
+ // <qmail> aFetchWillFollow parameter added
static CIpsPlgPop3ConnectOp* NewL(
CMsvSession& aMsvSession,
@@ -109,7 +116,8 @@
*/
// <qmail> MFSMailRequestObserver& changed to pointer
- // <qmail> aSignallingAllowed parameter removed
+ // <qmail> aSignallingAllowed parameter added
+ // <qmail> aFetchWillFollow parameter added
CIpsPlgPop3ConnectOp(
CMsvSession& aMsvSession,